summaryrefslogtreecommitdiffstats
path: root/interfaces
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /interfaces
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'interfaces')
-rw-r--r--interfaces/koChart.cc12
-rw-r--r--interfaces/koChart.h20
2 files changed, 17 insertions, 15 deletions
diff --git a/interfaces/koChart.cc b/interfaces/koChart.cc
index 692c7452..20d576ad 100644
--- a/interfaces/koChart.cc
+++ b/interfaces/koChart.cc
@@ -18,12 +18,12 @@
#include "koChart.h"
-#include <qobjectlist.h>
+#include <tqobjectlist.h>
using namespace KoChart;
WizardExtension::WizardExtension( Part *part, const char *name )
- : QObject( part, name )
+ : TQObject( part, name )
{
m_part = part;
}
@@ -32,10 +32,10 @@ WizardExtension::~WizardExtension()
{
}
-Part::Part( QWidget *parentWidget, const char *widgetName,
- QObject *parent, const char *name,
+Part::Part( TQWidget *tqparentWidget, const char *widgetName,
+ TQObject *tqparent, const char *name,
bool singleViewMode )
- : KoDocument( parentWidget, widgetName, parent, name, singleViewMode )
+ : KoDocument( tqparentWidget, widgetName, tqparent, name, singleViewMode )
{
}
@@ -45,7 +45,7 @@ Part::~Part()
WizardExtension *Part::wizardExtension()
{
- QObjectListIt it( *QObject::children() );
+ TQObjectListIt it( TQObject::childrenListObject() );
for (; it.current(); ++it )
if ( it.current()->inherits( "KoChart::WizardExtension" ) )
return static_cast<WizardExtension *>( it.current() );
diff --git a/interfaces/koChart.h b/interfaces/koChart.h
index 47cf4ae6..b185b9c3 100644
--- a/interfaces/koChart.h
+++ b/interfaces/koChart.h
@@ -19,7 +19,7 @@
#ifndef __koffice_kchart_h__
#define __koffice_kchart_h__
-#include <qvariant.h>
+#include <tqvariant.h>
#include <KoDocument.h>
#include <KDChartTable.h>
@@ -32,22 +32,23 @@ namespace KoChart
// KoChart::Value is either:
// - a double (interpreted as a value)
// - a QString (interpreted as a label)
// - a QDateTime (interpreted as a date/time value)
// - Invalid (interpreted as empty)
- typedef QVariant Value;
+ typedef TQVariant Value;
//typedef KDChartTableData Data;
- class KOCHARTINTERFACE_EXPORT WizardExtension : public QObject
+ class KOCHARTINTERFACE_EXPORT WizardExtension : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
WizardExtension( Part *part, const char *name = 0 );
virtual ~WizardExtension();
Part *part() const { return m_part; }
- virtual bool show( QString &area ) = 0;
+ virtual bool show( TQString &area ) = 0;
// XXX add more?
private:
@@ -59,9 +60,10 @@ namespace KoChart
class KOCHARTINTERFACE_EXPORT Part : public KoDocument
{
Q_OBJECT
+ TQ_OBJECT
public:
- Part( QWidget *parentWidget, const char *widgetName,
- QObject *parent, const char *name,
+ Part( TQWidget *tqparentWidget, const char *widgetName,
+ TQObject *tqparent, const char *name,
bool singleViewMode = false );
virtual ~Part();
@@ -72,7 +74,7 @@ namespace KoChart
#else
// The new interface.
virtual void resizeData( int rows, int columns ) = 0 ;
- virtual void setCellData( int row, int column, const QVariant &) = 0;
+ virtual void setCellData( int row, int column, const TQVariant &) = 0;
virtual void analyzeHeaders( ) = 0;
#endif
virtual void setCanChangeValue(bool b )=0;
@@ -32,22 +32,23 @@ namespace KoChart
// KoChart::Value is either:
// - a double (interpreted as a value)
- // - a QString (interpreted as a label)
- // - a QDateTime (interpreted as a date/time value)
+ // - a TQString (interpreted as a label)
+ // - a TQDateTime (interpreted as a date/time value)
// - Invalid (interpreted as empty)